# ink-autocomplete

> Text autocomplete component for [Ink](https://github.com/vadimdemedes/ink)


## Install

```
$ npm install ink-autocomplete
```

## Usage

__To autocomplete the input, press `tab` or `right` and the input will be filled with suggested value.__

```jsx
const {h, render, Component} = require('ink');
const AutoComplete = require('ink-autocomplete')

class Demo extends Component {
  constructor() {
    super()

    this.state = {
      value: ''
    }

    this.handleChange = this.handleChange.bind(this)
  }

  render(props, {value}) {
    return (
        <AutoComplete
          value={value}
          placeholder={'Type a country'}
          suggest={this.suggest}
          onChange={this.handleChange}
        />
    )
  }

  handleChange(value) {
    this.setState({ value })
  }

  suggest(input) {
    const options = ['United Kingdom', 'United States', 'France', 'Sweden', 'Slovenia']
    return options.filter(opt => opt.indexOf(input) === 0)[0]
  }
}

render(<Demo/>);
```

<img src="media/demo.gif" width="508">


## Props

#### value `string`
> Value of the input.

#### placeholder `string`
> String displayed when the input is empty.

#### suggest `function (string => string)`
> Function called each time user types in a new character. Input parameter is the current value of the input and the output should be the suggested value.

#### allowNew `boolean`
> Whether or not user can define new values.

#### focus `boolean`
> If text input is focused.

#### onChange `function (string => ())`
> Called each time input is changed and when `tab` or `right` key is pressed.

#### onSubmit `function (string => ())`
> Called when enter is pressed.

## License

MIT © [Matic Zavadlal](http://github.com/maticzav)
