'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _ink = require('ink');

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _diff = require('diff');

var _hasAnsi = require('has-ansi');

var _hasAnsi2 = _interopRequireDefault(_hasAnsi);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Helpers -------------------------------------------------------------------

const noop = () => {};
const getCharDiff = (t1, t2) => {
  if (t1 === t2) {
    return '';
  }

  var _diffChars = (0, _diff.diffChars)(t1, t2),
      _diffChars2 = _slicedToArray(_diffChars, 2);

  const tail = _diffChars2[1];


  return tail.value;
};

// AutoComplete --------------------------------------------------------------

class _class extends _ink.Component {

  constructor(props) {
    super(props);

    this.handleKeyPress = this.handleKeyPress.bind(this);
  }

  render() {
    var _props = this.props;
    const value = _props.value,
          suggest = _props.suggest,
          placeholder = _props.placeholder;


    const hasValue = value.length > 0;
    const suggestion = suggest(value);
    const tail = suggestion && hasValue ? getCharDiff(value, suggestion) : '';

    return (0, _ink.h)(
      'div',
      null,
      (0, _ink.h)(
        _ink.Text,
        { dim: !hasValue },
        hasValue ? value : placeholder
      ),
      (0, _ink.h)(
        _ink.Text,
        { dim: true },
        tail
      )
    );
  }

  componentDidMount() {
    process.stdin.on('keypress', this.handleKeyPress);
  }

  componentWillUnmount() {
    process.stdin.removeListener('keypress', this.handleKeyPress);
  }

  handleKeyPress(ch, key) {
    var _props2 = this.props;
    const value = _props2.value,
          suggest = _props2.suggest,
          onChange = _props2.onChange,
          allowNew = _props2.allowNew,
          onSubmit = _props2.onSubmit,
          focus = _props2.focus;

    const hasValue = value.length > 0;

    if (!focus) {
      return;
    }

    if (key.name === 'return') {
      onSubmit(value);
      return;
    }

    if (key.name === 'backspace') {
      onChange(value.slice(0, -1));
      return;
    }

    if (key.name === 'tab' || key.name === 'right') {
      if (hasValue && suggest(value)) {
        onChange(suggest(value));
      }
      return;
    }

    if ((0, _hasAnsi2.default)(key.sequence)) {
      return;
    }

    if (key.name === 'space' || key.sequence === ch && /^.*$/.test(ch) && !key.ctrl) {
      const newValue = value + ch;
      if (suggest(newValue) || allowNew) {
        onChange(value + ch);
      }
    }
  }

}

exports.default = _class; // ---------------------------------------------------------------------------

_class.propTypes = {
  value: _propTypes2.default.string,
  placeholder: _propTypes2.default.string,
  suggest: _propTypes2.default.func.isRequired,
  allowNew: _propTypes2.default.bool,
  focus: _propTypes2.default.bool,
  onChange: _propTypes2.default.func,
  onSubmit: _propTypes2.default.func
};
_class.defaultProps = {
  value: '',
  placeholder: '',
  allowNew: true,
  focus: true,
  onChange: noop,
  onSubmit: noop
};